from distutils.core import setup

setup(
  name = 'priest',
  packages = ['priest'], 
  version = '0.1',
  description = 'Generate wishes from your command line with full customization.',
  author = 'Ankush Sharma',
  author_email = 'ankprahsar@gmail.com',
  url = 'https://github.com/black-perl/priest', 
  download_url = 'https://github.com/black-perl/priest/tarball/0.1', 
  keywords = ['priest', 'automated-wishes'], 
  classifiers = []
)